==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/ECommerceServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.IECommerceService;
import pt.digitalis.dif.dem.managers.impl.model.data.EcommercePayments;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class ECommerceServiceImpl implements IECommerceService {

    /**
     * Obtains a new DataSet for the EcommercePayments entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<EcommercePayments> getEcommercePaymentsDataSet() {
        return new HibernateDataSet<EcommercePayments>(EcommercePayments.class, HibernateUtil.getSessionFactory("DIFRepository"),
                EcommercePayments.getPKFieldListAsString(), EcommercePayments.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == EcommercePayments.class)
            return getEcommercePaymentsDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(EcommercePayments.class.getSimpleName()))
            return getEcommercePaymentsDataSet();

        return null;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/impl/ECommerceServiceImpl.java <==
package pt.digitalis.dif.dem.managers.impl.model.impl;

import pt.digitalis.dif.model.hibernate.HibernateUtil;
import pt.digitalis.dif.model.dataset.IDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSet;
import pt.digitalis.dif.model.dataset.HibernateDataSetLegacyNoPK;
import pt.digitalis.utils.common.IBeanAttributes;

import pt.digitalis.dif.dem.managers.impl.model.DIFRepositoryFactory;
import pt.digitalis.dif.dem.managers.impl.model.IECommerceService;
import pt.digitalis.dif.dem.managers.impl.model.data.EcommercePayments;

/**
* NOTE: This file is auto generated and will be overwrite in a future file generation.
*/
public class ECommerceServiceImpl implements IECommerceService {

    /**
     * Constant with the session factory ID
     */
    public static String SESSION_FACTORY_NAME = "DIFRepository";

    /**
     * Obtains a new DataSet for the EcommercePayments entity
     *
     * @return A new HibernateDataSet instance
     */
    public HibernateDataSet<EcommercePayments> getEcommercePaymentsDataSet() {
        return new HibernateDataSet<EcommercePayments>(EcommercePayments.class, HibernateUtil.getSessionFactory(SESSION_FACTORY_NAME),
                EcommercePayments.getPKFieldListAsString(), EcommercePayments.FieldAttributes);
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param clazz
     *            the entity class
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(Class<? extends IBeanAttributes> clazz) {

        if (clazz == EcommercePayments.class)
            return getEcommercePaymentsDataSet();

        return null;
    }

    /**
     * Obtains a IDataSet for the given entity class
     *
     * @param entityName
     *            the entity class simple name
     * @return A new IDataSet instance
     */
    public HibernateDataSet<? extends IBeanAttributes> getDataSet(String entityName) {

        if (entityName.equalsIgnoreCase(EcommercePayments.class.getSimpleName()))
            return getEcommercePaymentsDataSet();

        return null;
    }
}
